@@ -8,6 +8,7 @@
 #' @param dimensions Optional, a \code{numeric} value or proportion of the dimensions to keep.
 #' @param verbose A \code{logical} value indicating whether to be verbose or not.
 #' @param boot.type The bootstrap algorithm to use (\code{default = "full"}; see details).
+#' @param prob Optional, a \code{matrix} or a \code{vector} of probabilities for each element to be selected during the bootstrap procedure. The \code{matrix} or the \code{vector} must have a rownames or names attribute that corresponds to the elements in \code{data}.
 #' 
 #' @return
 #' This function outputs a \code{dispRity} object containing:
@@ -18,12 +19,21 @@
 #' Use \link{summary.dispRity} to summarise the \code{dispRity} object.
 #'
 #' @details  
+#' \code{data}: The data is considered as the multidimensional space and is not transformed (e.g. if ordinated with negative eigen values, no correction is applied to the matrix).
+#' 
 #' \code{rarefaction}: when the input is \code{numeric}, the number of elements is set to the value(s) for each bootstrap. If some subsets have fewer elements than the rarefaction value, the subsets is not rarefied.
+#' 
 #' \code{boot.type}: the different bootstrap algorithms are:
 #' \itemize{
 #'   \item \code{"full"}: resamples all the rows of the matrix and replaces them with a new random sample of rows (with \code{replace = TRUE}, meaning all the elements can be duplicated in each bootstrap).
 #'   \item \code{"single"}: resamples only one row of the matrix and replaces it with a new randomly sampled row (with \code{replace = FALSE}, meaning that only one element can be duplicated in each bootstrap).
 #' }
+#' 
+#' \code{prob}: This option allows to attribute specific probability to each element to be drawn.
+#' A probability of 0 will never sample the element, a probability of 1 will sample.
+#' This can also be useful for weighting elements: an element with a weight of 10 will be sampled ten times more.
+#' If the argument is a \code{matrix}, it must have rownames attrbiutes corresponding to the element names.
+#' If the argument is a \code{vector}, it must have names attributes corresponding to the element names.
 #'
 #' @seealso \code{\link{cust.subsets}}, \code{\link{chrono.subsets}}, \code{\link{dispRity}}.
 #'
@@ -40,6 +50,8 @@
 #' boot.matrix(BeckLee_mat50, bootstraps = 20, rarefaction = c(7, 10, 11))
 #' ## Bootstrapping an ordinated matrix with only 3 dimensions
 #' boot.matrix(BeckLee_mat50, bootstraps = 20, dimensions = 3)
+#' ## Bootstrapping an the matrix but without sampling Cimolestes and sampling Maelestes 10x more
+#' boot.matrix(BeckLee_mat50, bootstraps = 20, prob = c("Cimolestes" = 0, "Maelestes" = 10))
 #' 
 #' ## Bootstrapping a subsets of matrices
 #' ## Generating a dummy subsets of matrices
@@ -68,7 +80,7 @@
 # bootstraps <- 3
 # rarefaction <- TRUE
 
-boot.matrix <- function(data, bootstraps = 100, rarefaction = FALSE, dimensions, verbose = FALSE, boot.type = "full") {
+boot.matrix <- function(data, bootstraps = 100, rarefaction = FALSE, dimensions, verbose = FALSE, boot.type = "full", prob) {
     
     parallel <- FALSE
 
@@ -93,10 +105,10 @@ boot.matrix <- function(data, bootstraps = 100, rarefaction = FALSE, dimensions,
         ## With the correct names
         data_names <- names(data)
         if(is.null(data_names)) {
-            stop(paste(match_call$data, "must be either a matrix or an output from the chrono.subsets or custom.subsets functions."))
+            stop(paste(as.expression(match_call$data), "must be either a matrix or an output from the chrono.subsets or custom.subsets functions."), call. = FALSE)
         } else {
             if(data_names[[1]] != "matrix" | data_names[[2]] != "call" | data_names[[3]] != "subsets") {
-                stop(paste(match_call$data, "must be either a matrix or an output from the chrono.subsets or custom.subsets functions."))
+                stop(paste(as.expression(match_call$data), "must be either a matrix or an output from the chrono.subsets or custom.subsets functions."), call. = FALSE)
             }
         }
 
@@ -118,6 +130,81 @@ boot.matrix <- function(data, bootstraps = 100, rarefaction = FALSE, dimensions,
         probabilistic_subsets <- ifelse(all(unique(unlist(lapply(data$subsets, lapply, ncol))) > 1), TRUE, FALSE)
     }
 
+    if(!missing(prob)) {
+        if(probabilistic_subsets) {
+            stop(paste0(as.expression(match_call$data), " was generated using a gradual time-slicing (", data$call$subsets[2], ").\nThe prob option is not yet implemented for this case."), call. = FALSE)
+            #warning(paste0(match_call$data, " was generated using a gradual time-slicing (", data$call$subsets[2], ").\nThe probabilities generated by chrono.subsets() are multiplied by prob." ))
+        } else {
+            probabilistic_subsets <- TRUE
+            ## Check if prob is the right class
+            class_prob <- check.class(prob, c("matrix", "numeric"))
+
+            ## Check if it has attributes
+            prob_names <- attributes(prob)
+            if(is.null(prob_names)) {
+                stop("prob argument must have names (vector) or dimnames (matrix) attributes.", call. = FALSE)
+            } else {
+                if(is.null(prob_names$names)) {
+                    prob_names <- prob_names$dimnames[[1]]
+                } else {
+                    prob_names <- names(prob)
+                }
+            }
+
+            ## Convert into a vector
+            if(class_prob == "matrix") {
+                prob <- as.vector(prob)
+                if(length(prob) !=  length(prob_names)) {
+                    stop("prob argument must be a matrix with one column only.", call. = FALSE)
+                } else {
+                    names(prob) <- prob_names 
+                }
+            }
+
+            ## Check the names
+            if(!all(prob_names %in% rownames(data$matrix))) {
+                stop(paste0("prob argument contains elements not present in ", as.expression(match_call$data), "."), call. = FALSE)
+            } else {
+                ## Check if they are any names missing
+                missing_rows <- rownames(data$matrix) %in% prob_names
+                if(any(missing_rows)) {
+                    extra_prob <- rep(1, length(which(!missing_rows)))
+                    names(extra_prob) <- rownames(data$matrix)[!missing_rows]
+                    prob <- c(extra_prob, prob)
+                }
+            }
+
+            ## Check the type of probability
+            if(any(prob < 0)) {
+                stop("Probabilities given to prob argument must be positive.", call. = FALSE)
+            }
+
+            ## Check if probabilities are weights
+            if(any(prob > 1)) {
+                prob <- prob/max(prob)
+            }
+
+            ## Renaming the elements to match the numbers in subsets
+            names(prob) <- match(names(prob), rownames(data$matrix))
+
+            ## Update the dispRity object
+            add.prob <- function(one_subset, prob) {
+
+                col1 <- one_subset$elements
+                col2 <- rep(NA, nrow(one_subset$elements))
+                col3 <- prob[match(one_subset$elements[,1], names(prob))]
+
+                ## Remove any attributes
+                attributes(col1) <- NULL
+                attributes(col3) <- NULL
+                one_subset$elements <- cbind(col1, col2, col3)
+                return(one_subset)
+            }
+
+            data$subsets <- lapply(data$subsets, add.prob, prob)
+        }
+    }
+
     ## BOOTSTRAP
     ## Must be a numeric value
     check.class(bootstraps, c("numeric", "integer"), " must be a single (integer) numerical value.")
@@ -150,8 +237,20 @@ boot.matrix <- function(data, bootstraps = 100, rarefaction = FALSE, dimensions,
     check.length(boot.type, 1, " must be a single character string")
     
     ## Must be one of these methods
-    check.method(boot.type, c("full", "single"))
-    
+    check.method(boot.type, c("full", "single"), "boot.type")
+
+    # boot.type_class <- class(boot.type)
+    # if(boot.type_class == "character") {
+    #     boot.type <- tolower(boot.type)
+    #     check.method(boot.type, c("full", "single"), "boot.type")
+    #     check.length(boot.type, 1, " must be \"full\", \"single\" or a matrix.")
+    # } else {
+    #     check.class(boot.type, "matrix")
+    #     if(!all(colnames(boot.type) == colnames(data$matrix))) {
+    #         stop("The personalised boot.type matrix must have the same rownames as the data.")
+    #     }
+    # }
+
     ## Check whether the subsets (if any)
 
     ## Set up the bootstrap type function
@@ -181,7 +280,7 @@ boot.matrix <- function(data, bootstraps = 100, rarefaction = FALSE, dimensions,
         check.length(dimensions, 1, " must be a proportional threshold value.", errorif = FALSE)
         if(dimensions < 0) stop("Number of dimensions to remove cannot be less than 0.")
         if(dimensions < 1) dimensions <- round(dimensions * ncol(data$matrix))
-        if(dimensions > ncol(data$matrix)) stop("Number of dimensions to remove cannot be more than the number of columns in the matrix.")
+        if(dimensions > ncol(data$matrix)) stop("Number of dimensions to remove cannot be more than the number of columns in the matrix.", call. = FALSE)
         data$call$dimensions <- dimensions
     } else {
         data$call$dimensions <- ncol(data$matrix)
