@@ -69,7 +69,7 @@ fill.dispRity <- function(data) {
     if(!is.null(data$matrix)) {
         check.class(data$matrix, "matrix")
     } else {
-        stop("dispRity object contains no matrix. Use:\nmake.dispRity(data = my_matrix)")
+        stop("dispRity object contains no matrix. Use:\nmake.dispRity(data = my_matrix)", call. = FALSE)
     }
 
     ## Dimensions
@@ -230,7 +230,7 @@ extract.dispRity <- function(data, subsets, observed = TRUE, rarefaction = FALSE
     check.class(data, "dispRity")
     ## Data must have disparity values
     if(is.null(data$call$disparity)) {
-        stop("dispRity object does not contain disparity values.")
+        stop("dispRity object does not contain disparity values.", call. = FALSE)
     }
 
     ## Observed
@@ -248,7 +248,7 @@ extract.dispRity <- function(data, subsets, observed = TRUE, rarefaction = FALSE
         check.class(rarefaction, c("numeric", "integer"))
         check.length(rarefaction, 1, errorif = FALSE, msg = "Only one rarefaction level can be used.")
         if(data$call$bootstrap[[3]][1] != "full" & any(is.na(match(rarefaction, data$call$bootstrap[[3]])))) {
-            stop("Rarefaction level not found.")
+            stop("Rarefaction level not found.", call. = FALSE)
         }
         if(observed) {warning("Observed value cannot be extract if rarefaction is not FALSE.")}
     } 
@@ -287,7 +287,7 @@ extract.dispRity <- function(data, subsets, observed = TRUE, rarefaction = FALSE
 #' ## Multiplying by 10 (dividing by 0.1)
 #' summary(rescale.dispRity(disparity, max = 0.1))
 #'
-#' @seealso \code{\link{dispRity}}, \code{\link{test.dispRity}}, \code{link[base]{scale}}.
+#' @seealso \code{\link{dispRity}}, \code{\link{test.dispRity}}, \code{\link[base]{scale}}.
 #'
 #' @author Thomas Guillerme
 #' @export
@@ -310,7 +310,7 @@ rescale.dispRity <- function(data, center = FALSE, scale = FALSE, use.all = TRUE
     ## data
     check.class(data, "dispRity")
     if(is.null(data$call$disparity)) {
-        stop("dispRity object does not contain disparity values.")
+        stop("dispRity object does not contain disparity values.", call. = FALSE)
     }
 
     ## Get the whole distribution
@@ -389,7 +389,7 @@ sort.dispRity <- function(x, decreasing = FALSE, sort, ...) {
     check.class(data, "dispRity")
     ## Initialising subsets length variable
     length_subsets <- length(data$subsets)
-    if(length_subsets == 1) stop("Data contains only one subset.")
+    if(length_subsets == 1) stop("The data contains no subsets.", call. = FALSE)
 
     ## decreasing
     check.class(decreasing, "logical")
@@ -399,7 +399,7 @@ sort.dispRity <- function(x, decreasing = FALSE, sort, ...) {
         check.class(sort, "numeric")
         check.length(sort, length_subsets, " must be the same length as the number of subsets in data.")
         if(all.equal(sort(sort), seq(from = 1, to = length_subsets)) != TRUE) {
-            stop(paste("Sort argument can only contain unique numbers between 1 and ", length_subsets, ".", sep = ""))
+            stop(paste("Sort argument can only contain unique numbers between 1 and ", length_subsets, ".", sep = ""), call. = FALSE)
         }
     } else {
         if(decreasing == FALSE) sort <- seq(from = 1, to = length_subsets)
@@ -487,21 +487,21 @@ combine.subsets <- function(data, subsets) {
     has_disparity <- ifelse(!is.null(data$call$disparity), TRUE, FALSE)
     has_bootstrap <- ifelse(!is.null(data$call$bootstrap), TRUE, FALSE)
     if(has_disparity && has_bootstrap) {
-        warning(paste(match_call$data, "contained bootstrap and disparity data that has been discarded in the output."))
+        warning(paste(as.expression(match_call$data), "contained bootstrap and disparity data that has been discarded in the output."))
         data$disparity <- NULL
         data$call$disparity <- NULL
         data$call$bootstrap <- NULL
         data$subsets <- lapply(data$subsets, select.elements)
     } else {
         if(has_disparity && !has_bootstrap) {
-            warning(paste(match_call$data, "contained disparity data that has been discarded in the output."))
+            warning(paste(as.expression(match_call$data), "contained disparity data that has been discarded in the output."))
             data$disparity <- NULL
             data$call$disparity <- NULL
         } else {
             if(!has_disparity && has_bootstrap) {
-                warning(paste(match_call$data, "contained bootstrap data that has been discarded in the output."))
+                warning(paste(as.expression(match_call$data), "contained bootstrap data that has been discarded in the output."))
                 data$call$bootstrap <- NULL
-                data$subsets <- lapply(data$subsets, "[[", 1)
+                data$subsets <- lapply(data$subsets, function(X){return(X[1])})
             }
         }
     }
@@ -512,34 +512,35 @@ combine.subsets <- function(data, subsets) {
         ## Subsamples is the minimum per subsets
         clean_data <- TRUE
         if(subsets > nrow(data$matrix)) {
-            stop(paste("Minimum sample size (", subsets, ") cannot be greater than the number of elements in the matrix (", nrow(data$matrix), ").", sep = ""))
+            stop(paste("Minimum sample size (", subsets, ") cannot be greater than the number of elements in the matrix (", nrow(data$matrix), ").", sep = ""), call. = FALSE)
         }
 
     } else {
+
+        if(length(data$subsets) < length(subsets)) {
+            stop(paste(as.expression(match_call$data), "does not contain enough subsets!"), call. = FALSE)
+        }
+
         clean_data <- FALSE
         ## Must be at least two long
-        if(length(subsets) < 2) stop("Subsamples argument must contain at least two values.")
+        if(length(subsets) < 2) stop("Subsamples argument must contain at least two values.", call. = FALSE)
         ## Must not contain duplicates
-        if(length(subsets) != length(unique(subsets))) stop("Subsamples argument must not contain duplicates.")
+        if(length(subsets) != length(unique(subsets))) stop("Subsamples argument must not contain duplicates.", call. = FALSE)
         if(subsets_class == "character") {
             ## Must be present in the subsets names
             matches <- subsets %in% names(data$subsets)
             if(any(matches == FALSE)) {
-                stop(paste(paste(subsets[!matches], collapse = " and "), "don't match with any of the subset names in", match_call$data))
+                stop(paste(paste(subsets[!matches], collapse = " and "), "don't match with any of the subset names in", match_call$data), call. = FALSE)
             } else {
                 subsets <- match(subsets, names(data$subsets))
             }
         } else {
             if(any(subsets > length(data$subsets))) {
-                stop(paste("subsets", paste(subsets[which(subsets > length(data$subsets))], collapse = " and "), "don't match with any of the subsets in", match_call$data))
+                stop(paste("subsets", paste(subsets[which(subsets > length(data$subsets))], collapse = " and "), "don't match with any of the subsets in", match_call$data), call. = FALSE)
             }
         }
     }
 
-    if(length(data$subsets) < length(subsets)) {
-        stop(paste(match_call$data, "does not contain enough subsets!"))
-    }
-
     if(clean_data) {
         ## Cleaning the data
         for(subs in 1:(length(data$subsets) - 1)) {
@@ -636,8 +637,8 @@ extinction.subsets <- function(data, extinction, lag = 1, names = FALSE, as.list
 
     ## data
     check.class(data, "dispRity")
-    if(is.null(data$subsets)) {
-        stop("data has no subsets. Use the chrono.subsets to generate some.")
+    if(length(data$subsets) < 2) {
+        stop("data has no subsets. Use the chrono.subsets to generate some.", call. = FALSE)
     }
 
     ## extinction
@@ -646,14 +647,14 @@ extinction.subsets <- function(data, extinction, lag = 1, names = FALSE, as.list
     ## check if the extinction is within the range
     data_range <- range(as.numeric(unlist(strsplit(names(data$subsets), split = " - "))))
     if(extinction < data_range[1] || extinction > data_range[2]) {
-        stop(paste0("extinction argument must be a numeric value between ", data_range[1], " and ", data_range[2], "."))
+        stop(paste0("extinction argument must be a numeric value between ", data_range[1], " and ", data_range[2], "."), call. = FALSE)
     }
 
     check.class(lag, c("numeric", "integer"))
     check.length(lag, 1, errorif = FALSE, msg = "lag argument must be a single numeric argument.")
     lag <- round(lag)
     if(lag < 1) {
-        stop("lag argument must be at least 1.")
+        stop("lag argument must be at least 1.", call. = FALSE)
     }
 
     check.class(names, "logical")
@@ -685,9 +686,9 @@ extinction.subsets <- function(data, extinction, lag = 1, names = FALSE, as.list
         lag <- length(data$subsets)
         warning(paste0("Lag is too long! It was automatically set to subset number ", lag, "."))
     }
-    if(extinction == lag) {
-        stop("No lag subset available after the extinction subset.")
-    }
+    # if(extinction == lag) {
+    #     stop("No lag subset available after the extinction subset.", call. = FALSE)
+    # }
 
     ## Adding the lag effect bins
     extinction_subset <- seq(from = extinction_subset, to = lag)
