@@ -7,6 +7,8 @@
 #' @param tree A \code{phylo} object matching the data and with a \code{root.time} element.
 #' @param nsim The number of simulations to calculate null disparity-through-time.
 #' @param model A evolutionary model for the simulations (see \code{\link[geiger]{sim.char}} - default is \code{"BM"}).
+#' @param alternative The H1 alternative (for calculating the p-value). Can be \code{"two-sided"} (default), \code{"greater"} or \code{"lesser"}; see details.
+#' @param ... Any other arguments to be passed to \code{\link[geiger]{dtt}}.
 #' 
 #' @details
 #' See \code{\link[geiger]{dtt}} for details. Note that for calculating the default metrics implemented in \code{\link[geiger]{dtt}} (i.e \code{c("avg.sq", "avg.manhattan", "num.states")}) this implementation in \code{dispRity} is much slower!
@@ -47,11 +49,30 @@
 # source("sanitizing.R")
 # source("dispRity_fun.R")
 # source("dtt.dispRity_fun.R")
+# geiger_data <- get(data(geospiza))
+# data = geiger_data$dat
+# average.sq <- function(X) mean(pairwise.dist(X)^2)
+# metric = average.sq
+# tree = geiger_data$phy
+# tree$root.time <- 5
+# nsim = 100
+# model = "BM"
+# #relative.disp = TRUE
+# alternative = "two-sided"
+# dots <- list()
+
+# set.seed(1)
+# dispRity_dtt <- dtt.dispRity(data = geiger_data$dat, metric = average.sq, tree = geiger_data$phy, nsim = 100, alternative = "two-sided", ...)
+# dispRity_dtt$p_value
+
+
+
 
 # Modified version of the geiger::dtt function (https://github.com/mwpennell/geiger-v2/blob/master/R/disparity.R)
-dtt.dispRity <- function(data, metric, tree, nsim = 0, model = "BM") {
+dtt.dispRity <- function(data, metric, tree, nsim = 0, model = "BM", alternative = "two-sided", ...) {
 
     match_call <- match.call()
+    dots <- list(...)
 
     ## SANITIZING
     ## data
@@ -65,7 +86,7 @@ dtt.dispRity <- function(data, metric, tree, nsim = 0, model = "BM") {
 
     ## Stop if data already contains disparity and metric is not level1
     if(!is.null(metrics_list$level3.fun) && length(data$call$disparity$metric) != 0) {
-        stop("Impossible to apply a dimension-level 3 metric on disparity data.")
+        stop("Impossible to apply a dimension-level 3 metric on disparity data.", call. = FALSE)
     }
 
     ## tree
@@ -83,8 +104,36 @@ dtt.dispRity <- function(data, metric, tree, nsim = 0, model = "BM") {
         warning("The following element(s) was not present in the tree: ", paste(cleaned_data$dropped_rows, collapse = ", "), ".")
     }
 
+    ## alternative
+    check.method(alternative, c("two-sided", "greater", "lesser"), msg = "alternative")
+    
+    ## Choose the p method
+    if(alternative == "two-sided") {
+        get.p.value <- function(sim_MDI, MDI, replicates) {
+            ## Centring the randoms and observed
+            center_random <- abs(sim_MDI - mean(sim_MDI))
+            center_observed <- abs(MDI - mean(sim_MDI))
+            ## Getting the p
+            return((sum(center_random >= center_observed))/(length(sim_MDI)))
+        }
+    }
+    if(alternative == "greater") {
+        get.p.value <- function(sim_MDI, MDI, replicates) {
+            # Getting the p
+            return((sum(sim_MDI >= MDI))/(length(sim_MDI)))
+        }
+    }
+    if(alternative == "lesser") {
+        get.p.value <- function(sim_MDI, MDI, replicates) {
+            # Getting the p
+            return((sum(sim_MDI <= MDI))/(length(sim_MDI)))
+        }
+    }
+
     ## mdi.range
-    mdi.range <- c(0,1)
+    if(is.null(dots$mdi.range)) {
+        dots$mdi.range <- c(0,1)
+    }
 
     ## Get the scaled disparity through time
     disparity_through_time <- .dtt.dispRity(tree, data, metric)
@@ -114,15 +163,28 @@ dtt.dispRity <- function(data, metric, tree, nsim = 0, model = "BM") {
         colnames(disparity_through_time_sim) <- NULL
 
         ## MDI
-        MDI <- unname(.area.between.curves(lineage_through_time, apply(disparity_through_time_sim, 1, median), disparity_through_time, sort(mdi.range)))
+        MDI <- unname(.area.between.curves(lineage_through_time, apply(disparity_through_time_sim, 1, median), disparity_through_time, sort(dots$mdi.range)))
 
-        ## Sort the output
-        output <- list(dtt = disparity_through_time, times = lineage_through_time, sim = disparity_through_time_sim, MDI = MDI)
+        ## Get the simulated MDIs
+        sim_MDI <- apply(disparity_through_time_sim, 2, function(X) .area.between.curves(x = lineage_through_time, f1 = X, f2 = disparity_through_time))
 
         ## Calculate the p_value
-        p_value <- getMDIp(output)
-        output <- c(output, p_value = p_value)
-    
+        p_value <- get.p.value(sim_MDI, MDI)
+
+        ## Sort the output
+        output <- list(dtt = disparity_through_time, times = lineage_through_time, sim = disparity_through_time_sim, MDI = MDI, sim_MDI = sim_MDI, p_value = p_value, call = match_call)
+
+        ## Add the model (if it was used as default)
+        if(is.null(output$call$model)) {
+            output$call$model <- model
+        }
+        if(is.null(output$call$alternative)) {
+            output$call$alternative <- alternative
+        }
+        
+        ## Calculate the p_value
+        p_value <- get.p.value(sim_MDI, MDI)
+
     } else {
 
         output <- list(dtt = disparity_through_time, times = lineage_through_time)
