@@ -47,9 +47,6 @@
 #' ## Measuring differences from a reference subset
 #' test.dispRity(sum_of_variances, wilcox.test, "referential")
 #'
-#' ## Running a linear model on the data
-#' test.dispRity(sum_of_variances, lm, "all")
-#'
 #' ## Measuring disparity as a distribution
 #' disparity_var <- dispRity(bootstrapped_data, metric = variances)
 #' ## Differences between the concatenated bootstrapped values of the subsets
@@ -102,9 +99,9 @@ test.dispRity <- function(data, test, comparisons = "pairwise", rarefaction = NU
     ## must be class dispRity...
     check.class(data, "dispRity")
     ## ...and have disparity data
-    if(is.null(data$call$disparity)) stop("Disparity has not been calculated yet.\nUse the dispRity() function to do so.\n", sep = "")
+    if(is.null(data$call$disparity)) stop("Disparity has not been calculated yet.\nUse the dispRity() function to do so.\n", sep = "", call. = FALSE)
     ## ...and must have more than one subsets
-    if(length(data$subsets) == 1) stop(paste(match_call$data, "must have more than one subset."))
+    if(length(data$subsets) == 1) stop(paste(as.expression(match_call$data), "must have more than one subset."), call. = FALSE)
 
     ## Check if disparity is a value or a distribution
     is_distribution <- ifelse(length(data$disparity[[1]]$elements) != 1, TRUE, FALSE)
@@ -113,10 +110,10 @@ test.dispRity <- function(data, test, comparisons = "pairwise", rarefaction = NU
     is_bootstrapped <- ifelse(!is.null(data$call$bootstrap), TRUE, FALSE)
 
     ## Stop if disparity is not a distribution, nor bootstrapped
-    if(!is_bootstrapped & !is_distribution) stop(paste(match_call$data, "is neither a distribution nor bootstrapped: impossible to compare single values."))
+    if(!is_bootstrapped & !is_distribution) stop(paste(as.expression(match_call$data), "is neither a distribution nor bootstrapped: impossible to compare single values."), call. = FALSE)
     
     ## Stop if disparity is not bootstrapped and rarefaction is required
-    if(!is_bootstrapped & !is.null(rarefaction)) stop("Impossible to use a rarefaction level for non-bootstrapped data.")
+    if(!is_bootstrapped & !is.null(rarefaction)) stop("Impossible to use a rarefaction level for non-bootstrapped data.", call. = FALSE)
 
     ## Test
     ## must be a single function
@@ -136,16 +133,18 @@ test.dispRity <- function(data, test, comparisons = "pairwise", rarefaction = NU
         check.class(comparisons, "list", paste(" must be either \"", paste(all_comparisons, collapse = "\", \""), "\" or list of one or more pairs of subsets.", sep = ""))
         
         ## must be pairs
-        if(length(unlist(comparisons))%%2 != 0) stop(paste(as.expression(match_call$comparisons), paste(" must be either \"", paste(all_comparisons, collapse = "\", \""), "\" or list of one or more pairs of subsets.", sep = ""), sep=""))    
+        if(length(unlist(comparisons))%%2 != 0) {
+            stop(paste(as.expression(match_call$comparisons), paste(" must be either \"", paste(all_comparisons, collapse = "\", \""), "\" or list of one or more pairs of subsets.", sep = ""), sep = ""), call. = FALSE)
+        }
         
         ## If character, input must match the subsets
         if(class(unlist(comparisons)) == "character") {
-            if(any(is.na(match(unlist(comparisons), data$subsets)))) stop(paste(as.expression(match_call$comparisons), ": at least one subset was not found.", sep=""))
+            if(any(is.na(match(unlist(comparisons), data$subsets)))) stop(paste(as.expression(match_call$comparisons), ": at least one subset was not found.", sep = ""), call. = FALSE)
         }
 
         ## If numeric, input must match de subsets numbers
         if(class(unlist(comparisons)) == "numeric") {
-            if(any(is.na(match(unlist(comparisons), seq(1:length(data$subsets)))))) stop(paste(as.expression(match_call$comparisons), ": at least one subset was not found.", sep=""))
+            if(any(is.na(match(unlist(comparisons), seq(1:length(data$subsets)))))) stop(paste(as.expression(match_call$comparisons), ": at least one subset was not found.", sep = ""), call. = FALSE)
         }
 
         ## Comparison is "custom"
@@ -153,7 +152,7 @@ test.dispRity <- function(data, test, comparisons = "pairwise", rarefaction = NU
     
     } else {
         ## Make sure only one inbuilt comparison is given
-        check.length(comparisons, 1, paste(" must be either", paste(all_comparisons, collapse = ", "), "."))        
+        check.length(comparisons, 1, paste(" must be either", paste(all_comparisons, collapse = ", "), "."))
         comp <- comparisons
 
         ## Set specific comparisons if needed
@@ -173,7 +172,7 @@ test.dispRity <- function(data, test, comparisons = "pairwise", rarefaction = NU
         check.class(rarefaction, c("numeric", "integer"))
         check.length(rarefaction, 1, errorif = FALSE, msg = "Only one rarefaction level can be used.")
         if(is.na(match(rarefaction, data$call$bootstrap[[3]]))) {
-            stop("Rarefaction level not found.")
+            stop("Rarefaction level not found.", call. = FALSE)
         }
     } else {
         rarefaction <- FALSE
@@ -182,7 +181,7 @@ test.dispRity <- function(data, test, comparisons = "pairwise", rarefaction = NU
     ## concatenate
     check.class(concatenate, "logical")
     if(!is_distribution && !concatenate) {
-        stop("Disparity is not calculated as a distribution, data cannot be concatenated (set concatenate = FALSE).")
+        stop("Disparity is not calculated as a distribution, data cannot be concatenated (set concatenate = FALSE).", call. = FALSE)
     }
 
     ## concatenate (ignore if data is not bootstrapped)
@@ -191,7 +190,7 @@ test.dispRity <- function(data, test, comparisons = "pairwise", rarefaction = NU
         ## conc.quantiles must be a list
         check.class(conc.quantiles, "list", " must be a list of at least one function and one quantile value (in that order).")
         
-        if(length(conc.quantiles) < 2) stop("conc.quantiles must be a list of at least one function and one quantile value (in that order).")
+        if(length(conc.quantiles) < 2) stop("conc.quantiles must be a list of at least one function and one quantile value (in that order).", call. = FALSE)
         
         ## first element of conc.quantiles must be a function
         con.cen.tend <- conc.quantiles[[1]]
@@ -200,7 +199,7 @@ test.dispRity <- function(data, test, comparisons = "pairwise", rarefaction = NU
         
         ## second and more elements must be numeric
         quantiles <- unlist(conc.quantiles[-1])
-        if(class(quantiles) != "numeric") stop("Quantiles provided in conc.quantiles must be stated after the function and must be numeric.")
+        if(class(quantiles) != "numeric") stop("Quantiles provided in conc.quantiles must be stated after the function and must be numeric.", call. = FALSE)
         if(sum(quantiles) != length(quantiles)) {
             conc.quantiles <- CI.converter(quantiles)
         } else {
@@ -211,7 +210,7 @@ test.dispRity <- function(data, test, comparisons = "pairwise", rarefaction = NU
     ## correction
     check.method(correction, c("holm", "hochberg", "hommel", "bonferroni", "BH", "BY", "fdr", "none"), "Correction methods")
     if(!is.null(data$call$bootstrap) && correction == "none" && length(data$subsets) > 2 && match_call$test != "adonis.dispRity") {
-        warning("Multiple p-values will be calculated without adjustment!\nThis will inflate Type I error!")
+        warning("Multiple p-values will be calculated without adjustment!\nThis can inflate Type I error!")
     }
 
     ## ----------------------
@@ -257,7 +256,9 @@ test.dispRity <- function(data, test, comparisons = "pairwise", rarefaction = NU
         ## running the tests
         try(details_out <- lapply(list_of_data, lapply.lm.type, test, ...), silent = TRUE)
         ## try(details_out <- lapply(list_of_data, lapply.lm.type, test), silent = TRUE) ; warning("DEBUG")
-        if(is.null(details_out)) stop(paste("Comparison type \"all\" is not applicable with", match_call$test))
+        if(is.null(details_out)) stop(paste("Comparison type \"all\" is not applicable with", as.expression(match_call$test)))
+
+        if(concatenate == FALSE) warning("Comparison type \"all\" is based on concatenated data.\nlm or aov type tests will have an inflated type I error!")
     }
 
     ## Sequential.test comparisons (one to each other)
@@ -348,26 +349,6 @@ test.dispRity <- function(data, test, comparisons = "pairwise", rarefaction = NU
         #     return(details_out)
         # }
 
-        ## Null.test results
-        if(details == FALSE && comp == "null.test") {
-            if(length(data$subsets) == 1) {
-                ## Return a single randtest already formatted.
-                return(details_out)
-            } else {
-                ## Saving the calling parameters
-                call <- paste("Monte-Carlo test from ade4::as.randtest with ", match_call$replicates, " replicates and alternative hypothesis set to be ", details_out[[1]]$alter, ".\n", "Null model was defined as: ", match_call$null.distrib, ".\nDisparity was measured as: ", get.metric.from.call(data), ".\n", sep ="")
-                ## Creating the results table
-                table_obs <- matrix(data = summary(data, round = 5)$observed, nrow = length(data$subsets), ncol = 1, dimnames = list(c(data$subsets)))
-                table_sta <- matrix(data =  unlist(lapply(details_out, function(X) return(c(X$expvar, X$pvalue)))), nrow = length(data$subsets), ncol = 4,  dimnames = list(c(data$subsets)), byrow = TRUE)
-
-                table_out <- cbind(table_obs, table_sta)
-                colnames(table_out) <- c("Obs.", "Std.Obs", "Expect", "Var", "p-value")
-
-                cat(call)
-                return(table_out)
-            }
-        }
-
         ## returning the detailed output
         return(details_out)
     }
